@@ -288,10 +288,10 @@ class EventManager:
 
             originalFrequency = 1
             factor = targetFrequency / originalFrequency
-            start = int(e.start * factor)
+            start = round(e.start * factor)
             if np.isnan(e.duration):
                 continue
-            duration = int(e.duration * factor)
+            duration = round(e.duration * factor)
             end = start + duration
             name = e.name
 
@@ -356,8 +356,6 @@ class EventManager:
             except EventNotListedException:
                 if raiseEventNotListed:
                     raise EventNotListedException()
-                if not eventValueName == self.defaultIgnoreValue:
-                    self.logWarning("Eventvalue '%s' was not listed in the specified eventgroup" % (eventValueName))
                 continue
 
             if eventName == self.defaultIgnoreValue:
