@@ -28,7 +28,7 @@ class Preprocessing:
 
         instance.targetChannels = preprocessingConfig["targetChannels"]
         instance.stepsByType = preprocessingConfig["stepsPerType"]
-        instance.forceGapBetweenEvents = preprocessingConfig["forceGapBetweenEvents"]
+        # instance.forceGapBetweenEvents = preprocessingConfig["forceGapBetweenEvents"]
         instance.eventConfig = {
             "extendEvents": preprocessingConfig["extendEvents"] if "extendEvents" in preprocessingConfig else None
         }
